﻿* Encoding: UTF-8.
*Descriptives/correlations prep

***Cluster and recode industries

Recode branch (2=2) (3=2) (4=2) (5=2) (6=1) (7=3) (8=3) (9=1) (10=1) (11=4) (12=5) (13=6) into branch_neu.
Variable labels branch_neu "Industry".

Value labels
branch_neu
1 'Services'
2 'Processing industries, manufacturing'
3 'Wholesale, retail'
4 'Public administration'
5 'Other'
6 'No resp'.
Execute.


*Compute dummy variables for controls

***Gender

Do repeat gender_r=gender_d1 to gender_d2 / genderval=1 to 2.
Recode gender (genderval=1) (else=0) into gender_r.
End repeat print.
Execute.

Variable labels gender_d1 for gender=1 'female'.
Variable labels gender_d2 for gender=2 'male'.
Execute.


***Educational background

Do repeat berabsch_r=berabsch_d1 to berabsch_d2 / berabschval=1 to 2.
Recode berabsch (berabschval=1) (else=0) into berabsch_r.
End repeat print.
Execute.

Variable labels berabsch_d1 for berabsch=1 'Apprenticeship'.
Variable labels berabsch_d2 for berabsch=2 'University)'.
Execute.

***Staff responsibility

Do repeat perver_r=perver_d1 to perver_d2 / perverval=1 to 2.
Recode perver (perverval=1) (else=0) into perver_r.
End repeat print.
Execute.

Variable labels perver_d1 for perver=1 'yes'.
Variable labels perver_d2 for perver=2 'no'.
Execute.

***Company size

Do repeat untgroe_r=untgroe_d1 to untgroe_d4 / untgroeval=1 to 4.
Recode untgroe (untgroeval=1) (else=0) into untgroe_r.
End repeat print.
Execute.

Variable labels untgroe_d1 for untgroe=1 '1-10 MA'.
Variable labels untgroe_d2 for untgroe=2 '11-499 MA'.
Variable labels untgroe_d3 for untgroe=3 '500-5000 MA'.
Variable labels untgroe_d4 for untgroe=4 '>5000 MA'.
Execute.


***Industries

Do repeat branch_neu_r=branch_neu_d1 to branch_neu_d5 / branch_neuval=1 to 5.
Recode branch_neu (branch_neuval=1) (else=0) into branch_neu_r.
End repeat print.
Execute.

Variable labels branch_neu_d1 for branch_neu=1 'Services'.
Variable labels branch_neu_d2 for branch_neu=2 'Processing industries, manufacturing'.
Variable labels branch_neu_d3 for branch_neu=3 'Wholesale, retail'.
Variable labels branch_neu_d4 for branch_neu=4 'Public administration'.
Variable labels branch_neu_d5 for branch_neu=5 'Other'.
Execute.



***Recode level 2 scale: Psychological climate

Recode forma_2r (1=4) (2=3) (3=2) (4=1) into forma_2.
Recode forma_4r (1=4) (2=3) (3=2) (4=1) into forma_4.
Recode forma_5r (1=4) (2=3) (3=2) (4=1) into forma_5.
Execute.

Compute supvi=mean(supvi_1, supvi_2, supvi_3, supvi_4, supvi_5).
Compute forma=mean(forma_1, forma_2, forma_3, forma_4, forma_5).
Compute innov=mean(innov_1, innov_2, innov_3, innov_4, innov_5, innov_6).
Execute.



***Reliability level 2 scale: Psychological climate

Reliability
/variables=supvi_1, supvi_2, supvi_3, supvi_4, supvi_5
/scale('supvi_scale') all
/model=alpha.
Execute.

Reliability
/variables=forma_1, forma_2, forma_3, forma_4, forma_5
/scale('forma_scale') all
/model=alpha.
Execute.

Reliability
/variables=innov_1, innov_2, innov_3, innov_4, innov_5, innov_6
/scale('innov_scale') all
/model=alpha.
Execute.



***Compute survey time, professional experience, tenure

Compute time_min=duration/60.
Execute.

COMPUTE ber_jam=ber_ja * 12.
EXECUTE.

Compute berufst_m=sum(ber_jam, ber_mo).
Execute.

COMPUTE unt_jam=unt_ja * 12.
EXECUTE.

Compute untzu_m=sum(unt_jam, unt_mo).
Execute.



***Correlations level 2 variables

CORRELATIONS
  /VARIABLES=supvi forma innov alter berufst_m untzu_m gender_d1 gender_d2 untgroe_d1 untgroe_d2 untgroe_d3 untgroe_d4 branch_neu_d1 branch_neu_d2 branch_neu_d3 branch_neu_d4 branch_neu_d5 berabsch_d1 berabsch_d2 perver_d1 perver_d2
  /PRINT=TWOTAIL NOSIG
  /STATISTICS DESCRIPTIVES
  /MISSING=PAIRWISE.
Execute.



***Descriptives and frequencies

descriptives berabsch abesch teilz untgroe gender alter branch branch_neu perver budver untber taetigk time_min berufst_m untzu_m.
Execute.

FREQUENCIES VARIABLES=berabsch abesch teilz untgroe gender alter branch branch_neu perver budver untber taetigk  
  /ORDER=ANALYSIS.
Execute.





**********************************************************************************




* Conjoint calculations

***Create new variable CJ_Order reflecting the CJ order used by each participant.

If ((nmiss(b111111i, c100100i, d111111i) = 3) & (nmiss(a010010i) = 0)) CJ_Order=1.
If ((nmiss(a010010i, c100100i, d111111i) = 3) & (nmiss(b111111i) = 0)) CJ_Order=2.
If ((nmiss(a010010i, b111111i, d111111i) = 3) & (nmiss(c100100i) = 0)) CJ_Order=3.
If ((nmiss(a010010i, b111111i, c100100i) = 3) & (nmiss(d111111i) = 0)) CJ_Order=4.
Execute.

***Assign labels to variables representing the right order.

Value labels
CJ_Order
1 'Order A'
2 'Order B'
3 'Order C'
4 'Order D'.
Execute.


***Recombining all four conjoint groups to one single group.
***Set 1

Compute set1_010010i=sum(a010010i, b010010i, c100100i, d100100i).
Execute.
Compute set1_001100i=sum(a001100i, b001100i, c000011i, d000011i).
Execute.
Compute set1_000111i=sum(a000111i, b000111i, c110001i, d110001i).
Execute.
Compute set1_101010i=sum(a101010i, b101010i, c101010i, d101010i).
Execute.
Compute set1_011001i=sum(a011001i, b011001i, c010110i, d010110i).
Execute.
Compute set1_110100i=sum(a110100i, b110100i, c001101i, d001101i).
Execute.
Compute set1_100001i=sum(a100001i, b100001i, c011000i, d011000i).
Execute.
Compute set1_111111i=sum(a111111i, b111111i, c111111i, d111111i).
Execute.

***Set 2

Compute set2_010010i=sum(a010010ir, b010010ir, c100100ir, d100100ir).
Execute.
Compute set2_001100i=sum(a001100ir, b001100ir, c000011ir, d000011ir).
Execute.
Compute set2_000111i=sum(a000111ir, b000111ir, c110001ir, d110001ir).
Execute.
Compute set2_101010i=sum(a101010ir, b101010ir, c101010ir, d101010ir).
Execute.
Compute set2_011001i=sum(a011001ir, b011001ir, c010110ir, d010110ir).
Execute.
Compute set2_110100i=sum(a110100ir, b110100ir, c001101ir, d001101ir).
Execute.
Compute set2_100001i=sum(a100001ir, b100001ir, c011000ir, d011000ir).
Execute.
Compute set2_111111i=sum(a111111ir, b111111ir, c111111ir, d111111ir).
Execute.


*** Transform conjoint profiles from columns to rows and keep the other variables fixed.

VARSTOCASES
/Make set1_innobehav from set1_010010i set1_001100i set1_000111i set1_101010i set1_011001i set1_110100i set1_100001i set1_111111i
/make set2_innobehav from set2_010010i set2_001100i set2_000111i set2_101010i set2_011001i set2_110100i set2_100001i set2_111111i
/index=CJ_Profile(set1_innobehav)
/keep=lfdn
external_lfdn
tester
dispcode
lastpage
quality
duration
p_0001
p_0002
berabsch
abesch
teilz
untgroe
gender
alter
schab_s
schab_sn
fastu
fastu_n
bndesl_s
kinder_s
famst_s
berpo_s
berpo_sn
trad_1s
trad_2s
trap_s
trad_3s
trad4_s
schab_a
schab_an
faaus
faaus_n
bndesl_a
kinder_a
fams_a
berpo_a
berpo_an
trad_1a
trad_2a
trap_a
trad_3a
trad_4a
branch
branch_n
untber
untber_n
taetigk
ber_ja
ber_mo
unt_ja
unt_mo
bertitel
berbez
gehalt
perver
perver_n
budver
budver_n
hierges
hierges_n
hiermit
hiermit_n
hierfrei
untalt
untalt_n
extver_r
agrabl
consci_r
neurot_r
openn_r
extver
agrabl_r
consci
neurot
openn
r_orgst
r_untent
r_arbed
r_expk
r_anpdr
r_fkult
d_orgst
d_untent
d_arbed
d_expk
d_anpdr
d_fkult
a_bsp_i
a_bsp_p
a010010i
a010010p
a001100i
a001100p
a000111i
a000111p
a101010i
a101010p
a011001i
a011001p
a110100i
a110100p
a100001i
a100001p
a111111i
a111111p
a010010ir
a010010pr
a001100ir
a001100pr
a000111ir
a000111pr
a101010ir
a101010pr
a011001ir
a011001pr
a110100ir
a110100pr
a100001ir
a100001pr
a111111ir
a111111pr
b_bsp_i
b_bsp_p
b111111i
b111111p
b100001i
b100001p
b110100i
b110100p
b011001i
b011001p
b101010i
b101010p
b000111i
b000111p
b001100i
b001100p
b010010i
b010010p
b111111ir
b111111pr
b100001ir
b100001pr
b110100ir
b110100pr
b011001ir
b011001pr
b101010ir
b101010pr
b000111ir
b000111pr
b001100ir
b001100pr
b010010ir
b010010pr
c_bsp_i
c_bsp_p
c100100i
c100100p
c000011i
c000011p
c110001i
c110001p
c101010i
c101010p
c010110i
c010110p
c001101i
c001101p
c011000i
c011000p
c111111i
c111111p
c100100ir
c100100pr
c000011ir
c000011pr
c110001ir
c110001pr
c101010ir
c101010pr
c010110ir
c010110pr
c001101ir
c001101pr
c011000ir
c011000pr
c111111ir
c111111pr
d_bsp_i
d_bsp_p
d111111i
d111111p
d011000i
d011000p
d001101i
d001101p
d010110i
d010110p
d101010i
d101010p
d110001i
d110001p
d000011i
d000011p
d100100i
d100100p
d111111ir
d111111pr
d011000ir
d011000pr
d001101ir
d001101pr
d010110ir
d010110pr
d101010ir
d101010pr
d110001ir
d110001pr
d000011ir
d000011pr
d100100ir
d100100pr
s_ind_1
s_ind_2
s_ind_3
s_ind_4
s_ind_5
s_ind_6
s_ind_7
s_dem_1
s_dem_2
s_dem_3
s_dem_4
s_dem_5
s_dem_6
s_dem_7
s_dem_8
s_dem_9
s_bet_1
s_bet_2
s_bet_3
s_bet_4
s_agi_1
s_agi_2
s_agi_3
s_agi_4
s_net_1
s_net_2
s_net_3
s_net_4
s_net_5
s_net_6
s_net_7
selbst_1
macht_1
univ_1
leist_1
sich_1
stim_1
konf_1
univ_2
trad_1
hedon_1
selbst_2
benev_1
leist_2
sich_2
stim_2
konf_2
macht_2
benev_2
univ_3
trad_2
hedon_2
selbst_1f
macht_1f
univ_1f
leist_1f
sich_1f
stim_1f
konf_1f
univ_2f
trad_1f
hedon_1f
selbst_2f
benev_1f
leist_2f
sich_2f
stim_2f
konf_2f
macht_2f
benev_2f
univ_3f
trad_2f
hedon_2f
auton_1
auton_2
auton_3r
auton_4r
auton_5r
supvi_1
supvi_2
supvi_3
supvi_4
supvi_5
train_1r
train_2
train_3r
train_4
welfa_1r
welfa_2
welfa_3
welfa_4
forma_1
forma_2r
forma_3
forma_4r
forma_5r
innov_1
innov_2
innov_3
innov_4
innov_5
innov_6
effor_1
effor_2
effor_3r
effor_4
effor_5r
pefed_1
pefed_2r
pefed_3r
pefed_4
pefed_5r
quali_1
quali_2
quali_3
quali_4r
ext_host
ip_addr
browser
referer
device_type
participant_browser
participant_browser_version
participant_os
participant_device
participant_brand
participant_model
participant_isbot
participant_continent
participant_country
participant_region
participant_city
participant_latitude
participant_longitude
quota
quota_assignment
page_history
hflip
vflip
output_mode
javascript
flash
session_id
language
cleaned
ats
datetime
date_of_last_access
date_of_first_mail
rts3572168
rts3572169
rts3572174
rts3572178
rts3572179
rts3572180
rts3572181
rts3572182
rts3572183
rts3572184
rts3572185
rts3572186
rts3572195
rts3572212
rts3572213
rts3572214
rts3572215
rts3572216
rts3572217
rts3572218
rts3572219
rts3572220
rts3572229
rts3572246
rts3572247
rts3572248
rts3572249
rts3572250
rts3572251
rts3572252
rts3572253
rts3572255
rts3572257
rts3572258
rts3572259
rts3572260
rts3592346
rts3596306
rts3596309
rts3596310
rts3596311
rts3596312
rts3596313
rts3596314
rts3596315
rts3596318
rts3596322
rts3596323
rts3596324
rts3596325
rts3596326
rts3596327
rts3596328
rts3596340
rts3596341
rts3596342
rts3596344
rts3596346
rts3596347
rts3596349
rts3596351
rts3596577
rts3596578
rts3596579
rts3596580
rts3596581
rts3596582
rts3596583
rts3596585
rts3596586
rts3596588
rts3596589
rts3596590
rts3596591
rts3596592
rts3596593
rts3596594
rts3596600
rts3596601
rts3596602
rts3596603
rts3596604
rts3596605
rts3596606
rts3596608
rts3646844
rts3647035
rts3668075
rts3672313
rts3672802
rnd_pg_3572177
select
branch_neu
gender_d1
gender_d2
berabsch_d1
berabsch_d2
perver_d1
perver_d2
untgroe_d1
untgroe_d2
untgroe_d3
untgroe_d4
branch_neu_d1
branch_neu_d2
branch_neu_d3
branch_neu_d4
branch_neu_d5
forma_2
forma_4
forma_5
supvi
forma
innov
time_min
ber_jam
berufst_m
unt_jam
untzu_m
/null=keep
/count=DV_generation_check "Number of cases created by transforming the CJ profiles from "+"columns to rows".
Execute.


***Profile order variable

If ((nmiss(b111111i, c100100i, d111111i) = 3) & (nmiss(a010010i) = 0)) CJ_Order=1.
If ((nmiss(a010010i, c100100i, d111111i) = 3) & (nmiss(b111111i) = 0)) CJ_Order=2.
If ((nmiss(a010010i, b111111i, d111111i) = 3) & (nmiss(c100100i) = 0)) CJ_Order=3.
If ((nmiss(a010010i, b111111i, c100100i) = 3) & (nmiss(d111111i) = 0)) CJ_Order=4.
Execute.


***Generate independent variables from each conjoint profile.

If (CJ_Order = 1) IV_org_structure=number(char.substr(CJ_Profile,6,1),N1.0).
If (CJ_Order = 1) IV_influence_company_decisions=number(char.substr(CJ_Profile,7,1),N1.0).
If (CJ_Order = 1) IV_influence_working_conditions=number(char.substr(CJ_Profile,8,1),N1.0).
If (CJ_Order = 1) IV_experimenting_culture=number(char.substr(CJ_Profile,9,1),N1.0).
If (CJ_Order = 1) IV_pressure_to_adapt=number(char.substr(CJ_Profile,10,1),N1.0).
If (CJ_Order = 1) IV_leadership_culture=number(char.substr(CJ_Profile,11,1),N1.0).
Execute.

If (CJ_Order = 2) IV_org_structure=number(char.substr(CJ_Profile,6,1),N1.0).
If (CJ_Order = 2) IV_influence_company_decisions=number(char.substr(CJ_Profile,7,1),N1.0).
If (CJ_Order = 2) IV_influence_working_conditions=number(char.substr(CJ_Profile,8,1),N1.0).
If (CJ_Order = 2) IV_experimenting_culture=number(char.substr(CJ_Profile,9,1),N1.0).
If (CJ_Order = 2) IV_pressure_to_adapt=number(char.substr(CJ_Profile,10,1),N1.0).
If (CJ_Order = 2) IV_leadership_culture=number(char.substr(CJ_Profile,11,1),N1.0).
Execute.

If (CJ_Order = 3) IV_org_structure=number(char.substr(CJ_Profile,8,1),N1.0).
If (CJ_Order = 3) IV_influence_company_decisions=number(char.substr(CJ_Profile,9,1),N1.0).
If (CJ_Order = 3) IV_influence_working_conditions=number(char.substr(CJ_Profile,10,1),N1.0).
If (CJ_Order = 3) IV_experimenting_culture=number(char.substr(CJ_Profile,11,1),N1.0).
If (CJ_Order = 3) IV_pressure_to_adapt=number(char.substr(CJ_Profile,6,1),N1.0).
If (CJ_Order = 3) IV_leadership_culture=number(char.substr(CJ_Profile,7,1),N1.0).
Execute.

If (CJ_Order = 4) IV_org_structure=number(char.substr(CJ_Profile,8,1),N1.0).
If (CJ_Order = 4) IV_influence_company_decisions=number(char.substr(CJ_Profile,9,1),N1.0).
If (CJ_Order = 4) IV_influence_working_conditions=number(char.substr(CJ_Profile,10,1),N1.0).
If (CJ_Order = 4) IV_experimenting_culture=number(char.substr(CJ_Profile,11,1),N1.0).
If (CJ_Order = 4) IV_pressure_to_adapt=number(char.substr(CJ_Profile,6,1),N1.0).
If (CJ_Order = 4) IV_leadership_culture=number(char.substr(CJ_Profile,7,1),N1.0).
Execute.



***Compute mean for each profile based on the decisions of set1 and set2.

Compute Innobehav=mean(set1_innobehav, set2_innobehav).
Execute.


*** Compute dichotomous control variables.

RECODE CJ_Order (1=1) (2=1) (3=2) (4=2) INTO Attr_Ord.
Variable Labels Attr_Ord 'Order of attributes in Conjoint Profiles'.
Execute.

RECODE CJ_Order (1=1) (2=2) (3=1) (4=2) INTO Prof_Ord.
Variable Labels Prof_Ord 'Order of appearances of Conjoint Profiles'.
Execute.


*** Rename Key Variables for further use in HLM (limit 8 digits).

Rename variables (lfdn=ID_participant).
Rename variables (IV_org_structure=orgstr).
Rename variables (IV_influence_company_decisions=icodec).
Rename variables (IV_influence_working_conditions=iwocon).
Rename variables (IV_experimenting_culture=expcul).
Rename variables (IV_pressure_to_adapt=pread).
Rename variables (IV_leadership_culture=leadcul).
Rename variables (Innobehav=innobeh).
Execute.



*** Compute test-retest correlations.

Sort cases by ID_participant.
split file separate by ID_participant.


CORRELATIONS
/variables=set1_innobehav set2_innobehav
/print=twotail nosig
/missing=pairwise.



*** Save HLM file with relevant variables.

SAVE OUTFILE='/Users/admin/02 Theurer et al._Data Conjoint Results_HLM Dataset_1180.sav'
  /DROP=external_lfdn
tester
dispcode
lastpage
quality
p_0001
p_0002
schab_s
schab_sn
fastu
fastu_n
bndesl_s
kinder_s
famst_s
berpo_s
berpo_sn
trad_1s
trad_2s
trap_s
trad_3s
trad4_s
schab_a
schab_an
faaus
faaus_n
bndesl_a
kinder_a
fams_a
berpo_a
berpo_an
trad_1a
trad_2a
trap_a
trad_3a
trad_4a
branch_n
untber_n
taetigk
ber_ja
ber_mo
unt_ja
unt_mo
bertitel
berbez
gehalt
perver_n
budver_n
hierges
hierges_n
hiermit
hiermit_n
hierfrei
untalt
untalt_n
extver_r
agrabl
consci_r
neurot_r
openn_r
extver
agrabl_r
consci
neurot
openn
r_orgst
r_untent
r_arbed
r_expk
r_anpdr
r_fkult
d_orgst
d_untent
d_arbed
d_expk
d_anpdr
d_fkult
a_bsp_i
a_bsp_p
a010010i
a010010p
a001100i
a001100p
a000111i
a000111p
a101010i
a101010p
a011001i
a011001p
a110100i
a110100p
a100001i
a100001p
a111111i
a111111p
a010010ir
a010010pr
a001100ir
a001100pr
a000111ir
a000111pr
a101010ir
a101010pr
a011001ir
a011001pr
a110100ir
a110100pr
a100001ir
a100001pr
a111111ir
a111111pr
b_bsp_i
b_bsp_p
b111111i
b111111p
b100001i
b100001p
b110100i
b110100p
b011001i
b011001p
b101010i
b101010p
b000111i
b000111p
b001100i
b001100p
b010010i
b010010p
b111111ir
b111111pr
b100001ir
b100001pr
b110100ir
b110100pr
b011001ir
b011001pr
b101010ir
b101010pr
b000111ir
b000111pr
b001100ir
b001100pr
b010010ir
b010010pr
c_bsp_i
c_bsp_p
c100100i
c100100p
c000011i
c000011p
c110001i
c110001p
c101010i
c101010p
c010110i
c010110p
c001101i
c001101p
c011000i
c011000p
c111111i
c111111p
c100100ir
c100100pr
c000011ir
c000011pr
c110001ir
c110001pr
c101010ir
c101010pr
c010110ir
c010110pr
c001101ir
c001101pr
c011000ir
c011000pr
c111111ir
c111111pr
d_bsp_i
d_bsp_p
d111111i
d111111p
d011000i
d011000p
d001101i
d001101p
d010110i
d010110p
d101010i
d101010p
d110001i
d110001p
d000011i
d000011p
d100100i
d100100p
d111111ir
d111111pr
d011000ir
d011000pr
d001101ir
d001101pr
d010110ir
d010110pr
d101010ir
d101010pr
d110001ir
d110001pr
d000011ir
d000011pr
d100100ir
d100100pr
s_ind_1
s_ind_2
s_ind_3
s_ind_4
s_ind_5
s_ind_6
s_ind_7
s_dem_1
s_dem_2
s_dem_3
s_dem_4
s_dem_5
s_dem_6
s_dem_7
s_dem_8
s_dem_9
s_bet_1
s_bet_2
s_bet_3
s_bet_4
s_agi_1
s_agi_2
s_agi_3
s_agi_4
s_net_1
s_net_2
s_net_3
s_net_4
s_net_5
s_net_6
s_net_7
selbst_1
macht_1
univ_1
leist_1
sich_1
stim_1
konf_1
univ_2
trad_1
hedon_1
selbst_2
benev_1
leist_2
sich_2
stim_2
konf_2
macht_2
benev_2
univ_3
trad_2
hedon_2
selbst_1f
macht_1f
univ_1f
leist_1f
sich_1f
stim_1f
konf_1f
univ_2f
trad_1f
hedon_1f
selbst_2f
benev_1f
leist_2f
sich_2f
stim_2f
konf_2f
macht_2f
benev_2f
univ_3f
trad_2f
hedon_2f
auton_1
auton_2
auton_3r
auton_4r
auton_5r
supvi_1
supvi_2
supvi_3
supvi_4
supvi_5
train_1r
train_2
train_3r
train_4
welfa_1r
welfa_2
welfa_3
welfa_4
forma_1
forma_2r
forma_3
forma_4r
forma_5r
innov_1
innov_2
innov_3
innov_4
innov_5
innov_6
effor_1
effor_2
effor_3r
effor_4
effor_5r
pefed_1
pefed_2r
pefed_3r
pefed_4
pefed_5r
quali_1
quali_2
quali_3
quali_4r
ext_host
ip_addr
browser
referer
device_type
participant_browser
participant_browser_version
participant_os
participant_device
participant_brand
participant_model
participant_isbot
participant_continent
participant_country
participant_region
participant_city
participant_latitude
participant_longitude
quota
quota_assignment
page_history
hflip
vflip
output_mode
javascript
flash
session_id
language
cleaned
ats
datetime
date_of_last_access
date_of_first_mail
rts3572168
rts3572169
rts3572174
rts3572178
rts3572179
rts3572180
rts3572181
rts3572182
rts3572183
rts3572184
rts3572185
rts3572186
rts3572195
rts3572212
rts3572213
rts3572214
rts3572215
rts3572216
rts3572217
rts3572218
rts3572219
rts3572220
rts3572229
rts3572246
rts3572247
rts3572248
rts3572249
rts3572250
rts3572251
rts3572252
rts3572253
rts3572255
rts3572257
rts3572258
rts3572259
rts3572260
rts3592346
rts3596306
rts3596309
rts3596310
rts3596311
rts3596312
rts3596313
rts3596314
rts3596315
rts3596318
rts3596322
rts3596323
rts3596324
rts3596325
rts3596326
rts3596327
rts3596328
rts3596340
rts3596341
rts3596342
rts3596344
rts3596346
rts3596347
rts3596349
rts3596351
rts3596577
rts3596578
rts3596579
rts3596580
rts3596581
rts3596582
rts3596583
rts3596585
rts3596586
rts3596588
rts3596589
rts3596590
rts3596591
rts3596592
rts3596593
rts3596594
rts3596600
rts3596601
rts3596602
rts3596603
rts3596604
rts3596605
rts3596606
rts3596608
rts3646844
rts3647035
rts3668075
rts3672313
rts3672802
rnd_pg_3572177
time_min
berufst_m
untzu_m
select
forma_2
forma_4
forma_5
ber_jam
unt_jam
  /COMPRESSED.
